@@ -1,5 +1,5 @@
 from marshmallow import Schema, fields, validates, ValidationError
-from .validators import validate_username
+from .validators import validate_username, validate_password_length
 
 
 class DefaultResponseSchema(Schema):
@@ -17,9 +17,11 @@ class LoginSchema(Schema):
     grant_type = fields.String(default="password")
 
 
-class RegisterSchema(LoginSchema):
+class RegisterSchema(Schema):
     first_name = fields.String(required=True)
     last_name = fields.String(required=True)
+    username = fields.Email(required=True)
+    password = fields.String(required=True)
 
     @validates("first_name")
     def validate_first_name(self, value):
@@ -31,10 +33,20 @@ class RegisterSchema(LoginSchema):
         if not validate_username(value, silently=True):
             raise ValidationError("Last name must be a character [a-zA-Z]")
 
+    @validates("password")
+    def validate_password(self, value):
+        if not validate_password_length(value, silently=True):
+            raise ValidationError("Password length must be greater than or equal to 8")
+
 
 class RequestPasswordResetSchema(Schema):
     username = fields.Email(required=True)
 
 
 class PasswordResetSchema(Schema):
-    password = fields.String(required=True)
\ No newline at end of file
+    password = fields.String(required=True)
+
+    @validates("password")
+    def validate_password(self, value):
+        if not validate_password_length(value, silently=True):
+            raise ValidationError("Password length must be greater than or equal to 8")
