@@ -7,5 +7,7 @@ migrate = Migrate(db=db)
 
 
 def init_app(app: Flask):
-    directory = os.path.join(app.root_path, "migrations")
+    directory = os.path.join(
+        app.root_path, "migrations/" + os.getenv("ZEMFROG_ENV", "development").lower()
+    )
     migrate.init_app(app, directory=directory)
