@@ -24,8 +24,16 @@ def validate_email(value: str, silently=False):
 
 
 def validate_username(value: str, silently=False):
-    if not re.search(r"^([a-zA-Z]*)$", value):
+    if not re.search(r"^([a-zA-Z]+)$", value):
         if silently:
             return False
         raise SystemExit("Name must be a character [a-zA-Z]")
     return True
+
+
+def validate_password_length(value: str, silently=False):
+    if len(value) < 8:
+        if silently:
+            return False
+        raise SystemExit("Password length must be greater than or equal to 8")
+    return True
